@@ -35,7 +35,8 @@ class ReceiptResource:
         
         endpoint = self.__endpoint.format(shop_id=shop_id)
         
-        params = {"limit":limit, "offset":offset} | type
+        params = {"limit":limit, "offset":offset}
+        params.update(type)
         json = self.auth.request(endpoint=endpoint, params=params)
         
         return Response[Receipt](**json)
